pub trait AsFilename: Sealed { }Expand description
This trait is implemented for types that can be used as a filename when loading new
Library instances.
It is currently sealed and cannot be implemented or its methods called by users of this crate.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.